#csh

#high resolution (0.2 degree version)

gmtset BASEMAP_TYPE PLAIN
gmtset DEGREE_FORMAT 1
gmtset LABEL_FONT_SIZE 12
gmtset PAPER_MEDIA letter+

set rstring = "-R10.00/20/-35/-25"
set rstring2 = "-R10/20/-35/-25"
set rstring3 = "-R10/20/-35/-25"

set cmapa = all_cmap.log3
set cmap = wind_cmap.log3
set cmapl = topo_cmap

#makecpt -Cno_green -Qo -T-5/0/.25 > wind_cmap.log
#makecpt -Cno_green -T0/5/.5 >! $cmap
#makecpt -Cno_green -T-5/10/.5 >! ${cmap}2
#makecpt -Cno_green -I -T-5/0/.5 >! $cmapa
#makecpt -Cno_green -I -T-10/5/.5 >! ${cmapa}2
#makecpt -Cno_green -T0/10/.5 >! $cmap
#makecpt -Cno_green -I -T-10/0/.5 >! $cmapa

set bstring = "-Ba5f1WeSn/a5f1"

set jstring = "-JM3" 
set outfile = "log_6mo_inset.ps"

# generate GMT .grd file from topography data set; let me know if you want this
set infile = "/RAID/RAID1/loquathome/home/sgille/seabreeze/topo/topogrid.dat"
set topogrd = "/home/sgille/seabreeze_7yr/figures/topouse_hr.grd"
cat $infile | gawk -f topouse.awk | \
 xyz2grd -G$topogrd -L -I.2/.2 $rstring2 -F

# generate GMT ocean data file
set infile = "/home/sgille/seabreeze_7yr/read_block_amjjas.dat"
cat $infile | gawk -f amplitude.awk | \
 xyz2grd -Gtestfilea.dat -L -I.2/.2 $rstring2 -F

# convert .gmt files to ASCII
grd2xyz $topogrd >! topouse.xyz
grd2xyz testfilea.dat >! seabreeze.xyz

# start map by laying down basemap
psbasemap -Y8 $rstring $jstring $bstring -G255/255/255 -K -P >! $outfile

# merge topography and seabreeze data ASCII files
paste topouse.xyz seabreeze.xyz | \
 awk ' { c = $3 ; if ( c < 0 ) { c = -$6 ; } print $1 , $2 , c } ' \
 | xyz2grd -Gall.grd -L -I.2/.2 $rstring2 -F
# plot image map using merged color map
grdimage all.grd $jstring $rstring3 -T -C$cmapa -0 -K -O >> $outfile

# insert stars at measurement data points
echo 14.6 -28.3 | psxy $jstring $rstring -Sa.08 -W1/0/0/0 -G0/0/0 -O -K >> $outfile
echo 15.188 -26.919 | psxy $jstring $rstring -Sa.08 -W1/0/0/0 -G0/0/0 -O -K >> $outfile
echo 16.433 -28.550 | psxy $jstring $rstring -Sa.08 -W1/0/0/0 -G0/0/0 -O -K >> $outfile

# add coastline; command is repeated to refine river and lake mapping
pscoast $rstring $jstring $bstring -A1000./0/1 -W -O -K >> $outfile
pscoast $rstring $jstring $bstring -A30000./2/2 -W -O -K >> $outfile

# label as panel (a)
echo 17 -25.5 12 0 Helvetica 6 "a. April to Sept" | pstext $rstring \
 $jstring -O -K >> $outfile

#---------------------------------------------------------------

# repeat data conversion for October-March data
set infile = "/home/sgille/seabreeze_7yr/read_block_ondjfm.dat"
cat $infile | gawk -f amplitude.awk | \
 xyz2grd -Gtestfilea2.dat -L -I.2/.2 $rstring2 -F
grd2xyz testfilea2.dat >! seabreeze2.xyz

# merge topography and ocean data
paste topouse.xyz seabreeze2.xyz | \
 awk ' { c = $3 ; if ( c < 0 ) { c = -$6 ; } print $1 , $2 , c } ' \
 | xyz2grd -Gall2d.grd -L -I.2/.2 $rstring2 -F

set rstring = "-R10.01/20/-35/-25"
set bstring = "-Ba5f1wESn/a5f1"
psbasemap -X3. $rstring $jstring $bstring -G255/255/255 -K -O >> $outfile
grdimage all2d.grd $jstring $rstring3 -T -C$cmapa -0 -K -O >> $outfile

# insert stars at measurement data points
echo 14.6 -28.3 | psxy $jstring $rstring -Sa.08 -W1/0/0/0 -G0/0/0 -O -K >> $outfile
echo 15.188 -26.919 | psxy $jstring $rstring -Sa.08 -W1/0/0/0 -G0/0/0 -O -K >> $outfile
echo 16.433 -28.550 | psxy $jstring $rstring -Sa.08 -W1/0/0/0 -G0/0/0 -O -K >> $outfile

# add coastline; command is repeated to refine river and lake mapping
pscoast $rstring $jstring $bstring -A1000./0/1 -W -O -K >> $outfile
pscoast $rstring $jstring $bstring -A30000./2/2 -W -O -K >> $outfile

# label as panel (b)
echo 17. -25.5 12 0 Helvetica 6 "b. Oct to March" | pstext $rstring \
 $jstring -O >> $outfile

# add colorbar if needed

#gmtset COLOR_IMAGE tiles
#psscale -C$cmap -D1.6/-.35/3.2/.25h -L -N40 -O -K -P -V -Ba2:"diurnal amplitude (m/s)": >> $outfile
#gmtset COLOR_IMAGE adobe

#gmtset COLOR_IMAGE tiles
#psscale -C$cmapl -D5.2/-.35/3.2/.25h -N40 -L -O -P -V -B:"elevation": >> $outfile
#gmtset COLOR_IMAGE adobe



gmtset PAPER_MEDIA letter

# fix bounding boxes and adjust so that eps can be converted to jpg or other
#  formats
head -1 $outfile >! /tmp/$outfile
echo "%%BoundingBox: 34 532 543 832" >> /tmp/$outfile
tail +3 $outfile | grep -v BoundingBox >> /tmp/$outfile
\mv /tmp/$outfile $outfile

